If test data is too small, no spikes are detected and sorting fails.

Tests here use 2.5 s per file.

test data is stored at smb://ceph-gw02.hpc.swc.ucl.ac.uk/neuroinformatics/neuroinformatics/scratch/jziminski/ephys/test_data/steve_multi_run/1119617/time-short/rawdata

It should be stored in the repo like:

/home/joe/git-repos/swc_ephys/tests/data/steve_multi_run/rawdata
